==> centreon-web-24.04.20.tar.gz: centreon-web-24.04.20/www/front_src/src/ApiTokens/TokenListing/TokenListing.tsx <==
import { useSetAtom } from 'jotai';
import { useTranslation } from 'react-i18next';

import Divider from '@mui/material/Divider';

import { MemoizedListing as Listing, useResizeObserver } from '@centreon/ui';

import TokenCreationButton from '../TokenCreation';
import { labelApiToken } from '../translatedLabels';

import Actions from './Actions';
import Refresh from './Actions/Refresh';
import { useColumns } from './ComponentsColumn/useColumns';
import Title from './Title';
import { selectedRowAtom } from './atoms';
import { useStyles } from './tokenListing.styles';
import { useTokenListing } from './useTokenListing';

interface Props {
  id: string;
}

const TokenListing = ({ id = 'root' }: Props): JSX.Element | null => {
  const { classes } = useStyles();
  const { t } = useTranslation();
  const setSelectRow = useSetAtom(selectedRowAtom);

  const { width } = useResizeObserver<HTMLElement>({
    ref: document.getElementById(id)
  });

  const {
    dataListing,
    changePage,
    changeLimit,
    onSort,
    sortedField,
    sortOrder,
    refetch
  } = useTokenListing({});

  const { columns, selectedColumnIds, onSelectColumns, onResetColumns } =
    useColumns();

  const selectRow = (row): void => {
    setSelectRow(row);
  };

  return (
    <div className={classes.container}>
      <Title msg={t(labelApiToken)} />
      <Divider className={classes.divider} />
      <Listing
        innerScrollDisabled
        actions={
          <Actions
            buttonCreateToken={<TokenCreationButton />}
            refresh={
              <Refresh isLoading={dataListing?.isLoading} onRefresh={refetch} />
            }
            width={width}
          />
        }
        actionsBarMemoProps={[dataListing?.isLoading, width]}
        columnConfiguration={{ selectedColumnIds, sortable: true }}
        columns={columns}
        currentPage={(dataListing?.page || 1) - 1}
        getId={({ name, user }) => `${name}-${user.id}`}
        limit={dataListing?.limit}
        loading={dataListing?.isLoading}
        memoProps={[width]}
        rows={dataListing?.rows}
        sortField={sortedField}
        sortOrder={sortOrder}
        totalRows={dataListing?.total}
        onLimitChange={changeLimit}
        onPaginate={changePage}
        onResetColumns={onResetColumns}
        onRowClick={selectRow}
        onSelectColumns={onSelectColumns}
        onSort={onSort}
      />
    </div>
  );
};
export default TokenListing;

==> centreon-web-24.04.25.tar.gz: centreon-web-24.04.25/www/front_src/src/ApiTokens/TokenListing/TokenListing.tsx <==
import { useSetAtom } from 'jotai';
import { useTranslation } from 'react-i18next';

import Divider from '@mui/material/Divider';

import { MemoizedListing as Listing } from '@centreon/ui';

import TokenCreationButton from '../TokenCreation';
import { labelApiToken } from '../translatedLabels';

import Actions from './Actions';
import { useColumns } from './ComponentsColumn/useColumns';
import Title from './Title';
import { selectedRowAtom } from './atoms';
import { useStyles } from './tokenListing.styles';
import useListing from './useListing';
import useLoadData from './useLoadData';

const TokenListing = (): JSX.Element | null => {
  const { classes } = useStyles();
  const { t } = useTranslation();
  const setSelectRow = useSetAtom(selectedRowAtom);

  const { data, isLoading } = useLoadData();

  const { changePage, changeSort, page, setLimit, sortf, sorto } = useListing();

  const { columns, selectedColumnIds, onSelectColumns, onResetColumns } =
    useColumns();

  const selectRow = (row): void => {
    setSelectRow(row);
  };

  return (
    <div className={classes.container}>
      <Title msg={t(labelApiToken)} />
      <Divider className={classes.divider} />
      <Listing
        innerScrollDisabled
        actions={<Actions buttonCreateToken={<TokenCreationButton />} />}
        columnConfiguration={{ selectedColumnIds, sortable: true }}
        columns={columns}
        currentPage={(page || 1) - 1}
        getId={({ name, user }) => `${name}-${user.id}`}
        limit={data?.meta.limit}
        loading={isLoading}
        memoProps={[columns, page, sorto, sortf]}
        rows={data?.result}
        sortField={sortf}
        sortOrder={sorto}
        totalRows={data?.meta.total}
        onLimitChange={setLimit}
        onPaginate={changePage}
        onResetColumns={onResetColumns}
        onRowClick={selectRow}
        onSelectColumns={onSelectColumns}
        onSort={changeSort}
      />
    </div>
  );
};
export default TokenListing;
